@@ -23,7 +23,12 @@ Rcpp::RawVector serialize_OutlierTree(ModelOutputs *model_outputs)
         oarchive(*model_outputs);
     }
     ss.seekg(0, ss.end);
-    Rcpp::RawVector retval(ss.tellg());
+    std::stringstream::pos_type vec_size = ss.tellg();
+    if (vec_size <= 0) {
+        Rcpp::Rcerr << "Error: model is too big to serialize, resulting object will not be usable.\n" << std::endl;
+        return Rcpp::RawVector();
+    }
+    Rcpp::RawVector retval((size_t)vec_size);
     ss.seekg(0, ss.beg);
     ss.read(reinterpret_cast<char*>(&retval[0]), retval.size());
     return retval;
@@ -35,7 +40,7 @@ SEXP deserialize_OutlierTree(Rcpp::RawVector src)
     std::stringstream ss;
     ss.write(reinterpret_cast<char*>(&src[0]), src.size());
     ss.seekg(0, ss.beg);
-    std::unique_ptr<ModelOutputs> model_outputs = std::unique_ptr<ModelOutputs>(new ModelOutputs);
+    std::unique_ptr<ModelOutputs> model_outputs = std::unique_ptr<ModelOutputs>(new ModelOutputs());
     {
         cereal::BinaryInputArchive iarchive(ss);
         iarchive(*model_outputs);
@@ -1134,7 +1139,7 @@ Rcpp::List fit_OutlierTree(Rcpp::NumericVector arr_num, size_t ncols_numeric,
     std::vector<double> Xcpp;
     double *arr_num_C = set_R_nan_as_C_nan(&arr_num[0], Xcpp, arr_num.size(), nthreads);
 
-    std::unique_ptr<ModelOutputs> model_outputs = std::unique_ptr<ModelOutputs>(new ModelOutputs);
+    std::unique_ptr<ModelOutputs> model_outputs = std::unique_ptr<ModelOutputs>(new ModelOutputs());
     found_outliers = fit_outliers_models(*model_outputs,
                                          arr_num_C, ncols_numeric,
                                          &arr_cat[0], ncols_categ, &ncat[0],
@@ -1151,6 +1156,8 @@ Rcpp::List fit_OutlierTree(Rcpp::NumericVector arr_num, size_t ncols_numeric,
                                          min_ts);
 
     outp["serialized_obj"] = serialize_OutlierTree(model_outputs.get());
+    if (!Rf_xlength(outp["serialized_obj"]))
+        return outp;
     if (return_outliers) {
         outp["outliers_info"] = describe_outliers(*model_outputs,
                                                   arr_num_C,
